import { useState, useEffect } from 'react';

import s from './Timer.module.css';

interface IRenderProps {
  seconds: number;
  refresh: number;
}

interface TimerProps {
  time: number;
  isOpen: boolean;
  setIsOpen: React.Dispatch<React.SetStateAction<boolean>>;
  refresh: number;
  render: ({ seconds, refresh }: IRenderProps) => JSX.Element;
}

const Timer = ({
  time,
  isOpen,
  setIsOpen,
  refresh,
  render: TimerPresentation,
}: TimerProps) => {
  const [timeLeft, setTimeLeft] = useState<number>(0);

  useEffect(() => {
    setTimeLeft(time);
  }, [time]);

  useEffect(() => {
    const handleInterval = () =>
      timeLeft > 0 && isOpen && setTimeLeft(timeLeft - 1);

    const idInterval = setInterval(handleInterval, 1000);
    return () => clearInterval(idInterval);
  }, [timeLeft, isOpen]);

  const handleTimer = () => setIsOpen(isOpen ? false : true);

  return (
    <div className={s.timerWrapper}>
      <button className={s.timerBtn} onClick={handleTimer}>
        {isOpen ? 'Stop' : 'Start'}
      </button>
      <p>speed per tic : 1000 ms</p>
      <p>refresh speed {refresh} ms</p>
      <p>{timeLeft} sec</p>
      <TimerPresentation seconds={timeLeft} refresh={refresh} />
    </div>
  );
};

export default Timer;
